<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>About</source>
        <translation>Apie</translation>
    </message>
    <message>
        <location filename="../about.ui" line="34"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt Archiver&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt; font-weight:600;&quot;&gt;LXQt archyvavimo programa&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../about.ui" line="57"/>
        <source>A simple and desktop-agnostic Qt file archiver</source>
        <translation>Paprasta ir nuo darbalaukio aplinkos nepriklausanti Qt failų archyvavimo programa</translation>
    </message>
    <message>
        <location filename="../about.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;https://github.com/lxqt/lxqt-archiver&quot;&gt;https://github.com/lxqt/lxqt-archiver&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="91"/>
        <source>Authors</source>
        <translation>Autoriai</translation>
    </message>
    <message>
        <location filename="../about.ui" line="100"/>
        <source>Programming:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt Archiver is derived from the following programs:
* Engrampa of MATE desktop
* File Roller of Gnome desktop
</source>
        <translation>Programavimas:
* Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;

LXQt archyvavimo programa yra kilusi iš šių programų:
* Engrampa iš MATE darbalaukio
* File Roller iš Gnome darbalaukio
</translation>
    </message>
    <message>
        <location filename="../about.ui" line="117"/>
        <source>License</source>
        <translation>Licencija</translation>
    </message>
    <message>
        <location filename="../about.ui" line="126"/>
        <source>LXQt Archiver

Copyright (C) 2020 the LXQt Team

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</source>
        <translation>LXQt archyvavimo programa

Autorių teisės (C) 2020 LXQt komanda

Ši programa yra laisva programinė įranga; jūs galite ją platinti ir/arba
modifikuoti remdamiesi Free Software Foundation paskelbtomis
GNU Bendrosios Viešosios Licencijos sąlygomis; licencijos 2 versija
arba (jūsų pasirinkimu) bet kuria velesne versija.

Ši programa platinama, tikintis, kad ji bus naudinga,
tačiau BE JOKIŲ GARANTIJŲ; netgi be numanomos PARDAVIMO
ar TINKAMUMO TAM TIKRAM TIKSLUI garantijos. Išsamiau apie tai,
žiūrėkite GNU Bendrojoje Viešojoje Licencijoje.

Kartu su šia programa turėjote gauti GNU Bendrosios Viešosios
Licencijos kopiją; jeigu jos negavote, rašykite Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.</translation>
    </message>
</context>
<context>
    <name>Archiver</name>
    <message>
        <location filename="../archiver.cpp" line="66"/>
        <source>Archive type not supported.</source>
        <translation>Archyvo tipas nepalaikomas.</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="310"/>
        <source>*%1 files (*%1)</source>
        <translation>*%1 failai (*%1)</translation>
    </message>
    <message>
        <location filename="../archiver.cpp" line="314"/>
        <source>All supported formats</source>
        <translation>Visi palaikomi formatai</translation>
    </message>
</context>
<context>
    <name>ArchiverError</name>
    <message>
        <location filename="../archivererror.cpp" line="25"/>
        <source>Failed to execute the command.</source>
        <translation>Nepavyko įvykdyti komandos.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="28"/>
        <source>Command is not found.</source>
        <translation>Komanda nerasta.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="31"/>
        <source>The command exited abnormally.</source>
        <translation>Komanda baigė darbą nenormaliai.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="34"/>
        <source>Password is required.</source>
        <translation>Reikalingas slaptažodis.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="37"/>
        <source>Missing volume.</source>
        <translation>Trūksta tomo.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="40"/>
        <source>Bad charset.</source>
        <translation>Blogas simbolių rinkinys.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="43"/>
        <source>Unsupported file format.</source>
        <translation>Nepalaikomas failo formatas.</translation>
    </message>
    <message>
        <location filename="../archivererror.cpp" line="46"/>
        <source>Unknown errors happened.</source>
        <translation>Atsirado nežinomų klaidų.</translation>
    </message>
</context>
<context>
    <name>CreateArchiveExtraWidget</name>
    <message>
        <location filename="../create.ui" line="26"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../create.ui" line="36"/>
        <source>Split into volumes of</source>
        <translation>Padalyti į tomus po</translation>
    </message>
    <message>
        <location filename="../create.ui" line="43"/>
        <source>Password:</source>
        <translation>Slaptažodis:</translation>
    </message>
    <message>
        <location filename="../create.ui" line="50"/>
        <source>Encrypt the file list too</source>
        <translation>Šifruoti taip pat ir failų sąrašą</translation>
    </message>
</context>
<context>
    <name>CreateFileDialog</name>
    <message>
        <location filename="../createfiledialog.cpp" line="13"/>
        <source>All files (*)</source>
        <translation>Visi failai (*)</translation>
    </message>
</context>
<context>
    <name>ExtractArchiveExtraWidget</name>
    <message>
        <location filename="../extract.ui" line="23"/>
        <source>Extract</source>
        <translation>Išpakuoti</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="29"/>
        <source>E&amp;xtract all files</source>
        <translation>Iš&amp;pakuoti visus failus</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="36"/>
        <source>Ex&amp;tract selected files</source>
        <translation>Iš&amp;pakuoti pažymėtus failus</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="59"/>
        <source>Actions</source>
        <translation>Veiksmai</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="65"/>
        <source>Re-create folders</source>
        <translation>Atkurti aplankų struktūrą</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="72"/>
        <source>Overwrite existing files</source>
        <translation>Perrašyti esamus failus</translation>
    </message>
    <message>
        <location filename="../extract.ui" line="79"/>
        <source>Do not extract older files</source>
        <translation>Neišpakuoti senesnių failų</translation>
    </message>
</context>
<context>
    <name>ExtractFileDialog</name>
    <message>
        <location filename="../extractfiledialog.cpp" line="12"/>
        <source>All files (*)</source>
        <translation>Visi failai (*)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>File Archiver</source>
        <translation>Failų archyvavimo programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="62"/>
        <source>Filter Files...</source>
        <translation>Filtruoti failus...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>&amp;File</source>
        <translation>&amp;Failas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="98"/>
        <source>&amp;Edit</source>
        <translation>&amp;Taisa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>&amp;View</source>
        <translation>&amp;Rodinys</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>&amp;Icon Size</source>
        <translation>P&amp;iktogramų dydis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="147"/>
        <source>&amp;Help</source>
        <translation>Ž&amp;inynas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Main Toolbar</source>
        <translation>Pagrindinė įrankių juosta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <source>&amp;About</source>
        <translation>&amp;Apie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="195"/>
        <source>&amp;New</source>
        <translation>&amp;Naujas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="198"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>&amp;Open</source>
        <translation>A&amp;tverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="210"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>Save &amp;As</source>
        <translation>Įrašyti &amp;kaip</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Ctrl+Shift+S</source>
        <translation>Ctrl+Shift+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&amp;Extract</source>
        <translation>&amp;Išpakuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="235"/>
        <source>&amp;Test</source>
        <translation>Iš&amp;bandyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="238"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="246"/>
        <source>&amp;Properties</source>
        <translation>&amp;Savybės</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="249"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="258"/>
        <source>&amp;Close</source>
        <translation>&amp;Užverti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="261"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Cu&amp;t</source>
        <translation>Iškirp&amp;ti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>&amp;Copy</source>
        <translation>&amp;Kopijuoti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="291"/>
        <source>&amp;Paste</source>
        <translation>Į&amp;dėti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="294"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="302"/>
        <source>&amp;Rename</source>
        <translation>Pe&amp;rvadinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <source>&amp;Delete</source>
        <translation>Iš&amp;trinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="318"/>
        <source>&amp;Select All</source>
        <translation>Ž&amp;ymėti viską</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>&amp;Find</source>
        <translation>&amp;Rasti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Add Files</source>
        <translation>&amp;Pridėti failus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="350"/>
        <source>Add F&amp;older</source>
        <translation>Pridėti a&amp;planką</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Pass&amp;word</source>
        <translation>S&amp;laptažodis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="366"/>
        <source>&amp;Toolbar</source>
        <translation>Į&amp;rankių juosta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>&amp;Statusbar</source>
        <translation>&amp;Būsenos juosta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>&amp;Directory Tree</source>
        <translation>&amp;Katalogų medis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="399"/>
        <source>S&amp;how as Folder</source>
        <translation>Ro&amp;dyti kaip aplanką</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <source>Ctrl+Shift+D</source>
        <translation>Ctrl+Shift+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>Show &amp;All Files</source>
        <translation>Rodyti &amp;visus failus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>St&amp;op</source>
        <translation>St&amp;abdyti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="425"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>&amp;Reload</source>
        <translation>Į&amp;kelti iš naujo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="433"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="438"/>
        <source>Filename &amp;Encoding</source>
        <translation>Failų pavadinimų &amp;koduotė</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="443"/>
        <source>&amp;View Selected Items</source>
        <translation>&amp;Rodyti pažymėtus elementus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>&amp;Filter</source>
        <translation>&amp;Filtras</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Expand</source>
        <translation>&amp;Išskleisti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="462"/>
        <source>Ctrl+Shift+E</source>
        <translation>Ctrl+Shift+E</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <source>Ctrl+Shift+C</source>
        <translation>Ctrl+Shift+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>&amp;Collapse</source>
        <translation>&amp;Suskleisti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <source>16 px</source>
        <translation>16 piks.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="489"/>
        <source>24 px</source>
        <translation>24 piks.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>32 px</source>
        <translation>32 piks.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="505"/>
        <source>48 px</source>
        <translation>48 piks.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <location filename="../mainwindow.cpp" line="420"/>
        <source>All files (*)</source>
        <translation>Visi failai (*)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Add only if &amp;newer</source>
        <translation>Pridėti tik tuo atveju, jei &amp;naujesnis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Confirm</source>
        <translation>Patvirtinti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="450"/>
        <source>Are you sure you want to delete selected files?</source>
        <translation>Ar tikrai norite ištrinti pažymėtus failus?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Version: %1</source>
        <translation>Versija: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="830"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>Success</source>
        <translation>Pavyko</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="934"/>
        <source>No errors have been found.</source>
        <translation>Klaidų nerasta.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="912"/>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="997"/>
        <source>N/A</source>
        <translation>–</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1001"/>
        <source>Uncompressed Size:</source>
        <translation>Nesuglaudinto dydis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1003"/>
        <source>Compression Ratio:</source>
        <translation>Glaudinimo santykis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1058"/>
        <source>File name</source>
        <translation>Failo pavadinimas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1059"/>
        <source>File Type</source>
        <translation>Failo tipas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1060"/>
        <source>File Size</source>
        <translation>Failo dydis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1061"/>
        <source>Modified</source>
        <translation>Keistas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1062"/>
        <source>Encrypted</source>
        <translation>Šifruotas</translation>
    </message>
    <message numerus="yes">
        <location filename="../mainwindow.cpp" line="1088"/>
        <source>%n file(s)</source>
        <translation>
            <numerusform>%n failas</numerusform>
            <numerusform>%n failai</numerusform>
            <numerusform>%n failų</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <location filename="../passworddialog.ui" line="14"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="20"/>
        <source>Encrypt the file list</source>
        <translation>Šifruoti failų sąrašą</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="34"/>
        <source>Show password</source>
        <translation>Rodyti slaptažodį</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="48"/>
        <location filename="../passworddialog.cpp" line="60"/>
        <source>Password:</source>
        <translation>Slaptažodis:</translation>
    </message>
    <message>
        <location filename="../passworddialog.ui" line="61"/>
        <source>&lt;i&gt;&lt;b&gt;Note:&lt;/b&gt; the password will be used to encrypt files you add to the current archive, and to decrypt files you extract from the current archive. When the archive is closed the password will be deleted.&lt;/i&gt;</source>
        <translation>&lt;i&gt;&lt;b&gt;Pastaba:&lt;/b&gt; slaptažodis bus naudojamas šifruoti į dabartinį archyvą pridedamus failus ir iššifruoti iš dabartinio archyvo išpakuojamus failus. Užvėrus archyvą, slaptažodis bus ištrintas.&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <location filename="../progressdialog.ui" line="14"/>
        <source>Progress</source>
        <translation>Eiga</translation>
    </message>
    <message>
        <location filename="../progressdialog.cpp" line="16"/>
        <source>%p %</source>
        <translation>%p %</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="248"/>
        <location filename="../main.cpp" line="300"/>
        <source>Error</source>
        <translation>Klaida</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="6"/>
        <source>7-Zip (.7z)</source>
        <translation>7-Zip (.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="7"/>
        <source>Tar compressed with 7z (.tar.7z)</source>
        <translation>Tar glaudintas naudojant 7z (.tar.7z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="8"/>
        <source>Ace (.ace)</source>
        <translation>Ace (.ace)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="9"/>
        <source>Ar (.a)</source>
        <translation>Ar (.a)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="10"/>
        <source>Ar (.ar)</source>
        <translation>Ar (.ar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="11"/>
        <source>Arj (.arj)</source>
        <translation>Arj (.arj)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="12"/>
        <source>Tar compressed with bzip2 (.tar.bz2)</source>
        <translation>Tar glaudintas naudojant bzip2 (.tar.bz2)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="13"/>
        <source>Tar compressed with bzip (.tar.bz)</source>
        <translation>Tar glaudintas naudojant bzip (.tar.bz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="14"/>
        <source>Cabinet (.cab)</source>
        <translation>Cabinet (.cab)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="15"/>
        <source>Rar Archived Comic Book (.cbr)</source>
        <translation>Rar archyvuota komiksų knyga (.cbr)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="16"/>
        <source>Zip Archived Comic Book (.cbz)</source>
        <translation>Zip archyvuota komiksų knyga (.cbz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="17"/>
        <source>Tar compressed with gzip (.tar.gz)</source>
        <translation>Tar glaudintas naudojant gzip (.tar.gz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="18"/>
        <source>Ear (.ear)</source>
        <translation>Ear (.ear)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="19"/>
        <source>Self-extracting zip (.exe)</source>
        <translation>Išsipakuojantis zip (.exe)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="20"/>
        <source>Jar (.jar)</source>
        <translation>Jar (.jar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="21"/>
        <source>Lha (.lzh)</source>
        <translation>Lha (.lzh)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="22"/>
        <source>Lrzip (.lrz)</source>
        <translation>Lrzip (.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="23"/>
        <source>Tar compressed with lrzip (.tar.lrz)</source>
        <translation>Tar glaudintas naudojant lrzip (.tar.lrz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="24"/>
        <source>Tar compressed with lzip (.tar.lz)</source>
        <translation>Tar glaudintas naudojant lzip (.tar.lz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="25"/>
        <source>Tar compressed with lzma (.tar.lzma)</source>
        <translation>Tar glaudintas naudojant lzma (.tar.lzma)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="26"/>
        <source>Tar compressed with lzop (.tar.lzo)</source>
        <translation>Tar glaudintas naudojant lzop (.tar.lzo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="27"/>
        <source>Windows Imaging Format (.wim)</source>
        <translation>Windows atvaizdų formatas (.wim)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="28"/>
        <source>Rar (.rar)</source>
        <translation>Rar (.rar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="29"/>
        <source>Tar uncompressed (.tar)</source>
        <translation>Tar nesuglaudintas (.tar)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="30"/>
        <source>Tar compressed with compress (.tar.Z)</source>
        <translation>Tar glaudintas naudojant compress (.tar.Z)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="31"/>
        <source>War (.war)</source>
        <translation>War (.war)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="32"/>
        <source>Xz (.xz)</source>
        <translation>Xz (.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="33"/>
        <source>Tar compressed with xz (.tar.xz)</source>
        <translation>Tar glaudintas naudojant xz (.tar.xz)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="34"/>
        <source>Tar compressed with zstd (.tar.zst)</source>
        <translation>Tar glaudintas naudojant zstd (.tar.zst)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="35"/>
        <source>Zoo (.zoo)</source>
        <translation>Zoo (.zoo)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="36"/>
        <source>Zip (.zip)</source>
        <translation>Zip (.zip)</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="39"/>
        <location filename="../corestrs.h" line="46"/>
        <location filename="../corestrs.h" line="62"/>
        <location filename="../main.cpp" line="240"/>
        <source>Adding file: </source>
        <translation>Failo pridėjimas: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="40"/>
        <location filename="../corestrs.h" line="49"/>
        <location filename="../corestrs.h" line="64"/>
        <location filename="../main.cpp" line="282"/>
        <source>Extracting file: </source>
        <translation>Failo išskleidimas: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="43"/>
        <source>%d %B %Y, %H:%M</source>
        <translation>%Y %B %d, %H:%M</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="47"/>
        <location filename="../corestrs.h" line="63"/>
        <source>Removing file: </source>
        <translation>Failo šalinimas: </translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="48"/>
        <source>Deleting files from archive</source>
        <translation>Failų ištrynimas iš archyvo</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="50"/>
        <source>Recompressing archive</source>
        <translation>Archyvo glaudinimas iš naujo</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="51"/>
        <source>Decompressing archive</source>
        <translation>Archyvo išglaudinimas</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="54"/>
        <source>File not found.</source>
        <translation>Failas nerastas.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="55"/>
        <source>Archive type not supported.</source>
        <translation>Archyvo tipas nepalaikomas.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="56"/>
        <source>Archive not found</source>
        <translation>Archyvas nerastas</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="57"/>
        <source>You don&apos;t have the right permissions.</source>
        <translation>Neturite tinkamų leidimų.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="58"/>
        <source>This archive type cannot be modified</source>
        <translation>Šio archyvo tipo negalima keisti</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="59"/>
        <source>You can&apos;t add an archive to itself.</source>
        <translation>Negalite pridėti į archyvo patį į save.</translation>
    </message>
    <message>
        <location filename="../corestrs.h" line="65"/>
        <source>Could not find the volume: %s</source>
        <translation>Nepavyko rasti tomo: %s</translation>
    </message>
</context>
</TS>
